==> k3b-2.0.2.tar.xz: k3b-2.0.2/src/k3baction.h <==
/*
 *
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This file is part of the K3b project.
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */

#ifndef _K3B_ACTION_H_
#define _K3B_ACTION_H_

#include <QtCore/QObject>
#include <KIcon>
#include <KToggleAction>
#include <KActionCollection>

namespace K3b {
    /**
     * Create a KAction the old (way cooler) KDE3 way. Porting becomes a simple replacement.
     */
    KAction* createAction( QObject* parent,
                           const QString& text, const QString& icon, const
                           QKeySequence& shortcut, QObject* receiver, const char* slot,
                           KActionCollection* actionCollection = 0,
                           const QString& actionName = QString() );
    KToggleAction* createToggleAction( QObject* parent,
                                       const QString& text, const QString& icon, const
                                       QKeySequence& shortcut, QObject* receiver, const char* slot,
                                       KActionCollection* actionCollection = 0,
                                       const QString& actionName = QString() );
}

#endif

==> k3b-17.07.90.tar.xz: k3b-17.07.90/src/k3baction.h <==
/*
 *
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This file is part of the K3b project.
 * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */

#ifndef _K3B_ACTION_H_
#define _K3B_ACTION_H_

#include <KWidgetsAddons/KToggleAction>
#include <KXmlGui/KActionCollection>

#include <QtCore/QObject>
#include <QtGui/QIcon>
#include <QtWidgets/QAction>

namespace K3b {
    /**
     * Create a QAction the old (way cooler) KDE3 way. Porting becomes a simple replacement.
     */
    QAction* createAction( QObject* parent,
                           const QString& text, const QString& icon, const
                           QKeySequence& shortcut, QObject* receiver, const char* slot,
                           KActionCollection* actionCollection = 0,
                           const QString& actionName = QString() );
    KToggleAction* createToggleAction( QObject* parent,
                                       const QString& text, const QString& icon, const
                                       QKeySequence& shortcut, QObject* receiver, const char* slot,
                                       KActionCollection* actionCollection = 0,
                                       const QString& actionName = QString() );
}

#endif
